@@ -91,7 +91,7 @@ def getted_vars(thing, _getattr=getattr):
     # todo: can make "fallback" option, to use value from original `vars` if
     # get is unsuccessful.
     my_vars = vars(thing)
-    return {name: _getattr(thing, name) for name in my_vars.iterkeys()}
+    return dict((name, _getattr(thing, name)) for name in my_vars.iterkeys())
 
 
 
