@@ -1,4 +1,4 @@
-# Copyright 2009-2013 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''Testing module for `python_toolbox.abc_tools.AbstractStaticMethod`.'''
@@ -18,7 +18,7 @@ def test_cheat_hash():
         [1, 2, 3.4],
         (1, 2, 3.4),
         {1: 2, 3: 4.5},
-        {1, 2, 3.4},
+        set((1, 2, 3.4)),
         [1, [1, 2], 3],
         [1, {frozenset((1, 2)): 'meow'}, 3],
         sum,
