@@ -1,4 +1,4 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''Testing modules for `python_toolbox.misc_tools.ProxyProperty`.'''
@@ -11,13 +11,12 @@ from python_toolbox.misc_tools import ProxyProperty
 
 
 class Object(object):
-    ''' '''        
+    pass
 
 
 def test():
     
     class A(object):
-        ''' '''
         y = 'y'
         def __init__(self):
             self.x = 'x'
@@ -30,7 +29,7 @@ def test():
             '.y',
             doc='Proxy for `y`.'
         )
-        z_proxy = ProxyProperty('.obj.z')
+        z_proxy = ProxyProperty('.obj.z', doc='aye, this my favorite z.')
         uuid_proxy = ProxyProperty(
             '.uuid',
             'Object-specific UUID.'
@@ -70,6 +69,10 @@ def test():
     #                                                                         #
     ### Finished setting proxy-properties to different values. ################
 
+    assert repr(A.x_proxy) == '''<ProxyProperty: '.x'>'''
+    assert repr(A.z_proxy) == ('''<ProxyProperty: '.obj.z', doc='aye, this '''
+                               '''my favorite z.'>''')
+
 
 def test_dot():
     '''Text that `ProxyProperty` complains when there's no prefixing dot.'''
